<?php
/**
 * @file
 * Contains Drupal\digiteka\Form\DigitekaSettingsForm.
 */

namespace Drupal\digiteka\Form;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines the configuration export form.
 */
class DigitekaSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'digiteka_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'digiteka.adminsettings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('digiteka.adminsettings');

    // Disable completely.
    $form['digiteka_disable_all'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Disable Digiteka completely.'),
      '#description' => $this->t('If checked, Digiteka will be disabled sitewide.'),
      '#default_value' => $config->get('digiteka_disable_all'),
    ];

    // Debug mode.
    $form['digiteka_debug_mode'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable debug mode.'),
      '#description' => $this->t('If checked, admin users will be able to see the values used for the widget.'),
      '#default_value' => $config->get('digiteka_debug_mode'),
    ];

    // ID.
    $form['digiteka_mdtk'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Digiteka Id'),
      '#description' => $this->t('Digiteka Id'),
      '#default_value' => $config->get('digiteka_mdtk'),
      '#states' => [
        'disabled' => [
          ':input[name="digiteka_disable_all"]' => ['checked' => TRUE],
        ],
      ],
    ];

    // Field date name.
    $form['digiteka_field_date_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Field date name'),
      '#description' => $this->t('This value will be used by ULTIMEDIA_date. If empty, \'created\' will be used.'),
      '#default_value' => $config->get('digiteka_field_date_name'),
      '#states' => [
        'disabled' => [
          ':input[name="digiteka_disable_all"]' => ['checked' => TRUE],
        ],
      ],
    ];

    // Zones.
    $form['digiteka_zones'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Digiteka Zones'),
      '#description' => $this->t('Zone configuration. Term name:zone number separated by commas eg. News:3, Reviews:4.'),
      '#default_value' => $config->get('digiteka_zones'),
      '#states' => [
        'disabled' => [
          ':input[name="digiteka_disable_all"]' => ['checked' => TRUE],
        ],
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $form_elements = [
      'digiteka_disable_all',
      'digiteka_debug_mode',
      'digiteka_mdtk',
      'digiteka_field_date_name',
      'digiteka_zones'
    ];
    foreach ($form_elements as $element_name) {
      $this->config('digiteka.adminsettings')
        ->set($element_name, $form_state->getValue($element_name))
        ->save();
    }
    // Clear render cache.
    \Drupal::service('cache.render')->invalidateAll();
  }
}
