<?php

namespace Drupal\digiteka\Plugin\Block;

use Drupal\Core\Block\BlockBase;

/**
 * Provides a 'Digiteka' Block.
 *
 * @Block(
 *   id = "digiteka_block",
 *   admin_label = @Translation("Digiteka block"),
 *   category = @Translation("Digiteka"),
 * )
 */
class DigitekaBlock extends BlockBase {
  /**
   * {@inheritdoc}
   */
  public function build() {
    $node = \Drupal::routeMatch()->getParameter('node');
    $config = \Drupal::config('digiteka.adminsettings');

    // If it's not a node or Digiteka is disabled sitewide, return.
    if (!$node instanceof \Drupal\node\NodeInterface || $config->get('digiteka_disable_all')) {
      return [];
    }

    // Field date name default to created, unless it has a value.
    $field_date_name = 'created';
    if (!empty($config->get('digiteka_field_date_name'))) {
      $field_date_name = $config->get('digiteka_field_date_name');
    }
    $ultimedia_date = $node->get($field_date_name)->getValue();
    isset($ultimedia_date[0]['value']) ? $ultimedia_date = $ultimedia_date[0]['value'] : $ultimedia_date = '';

    // Default zone.
    $zone = 2;

    // Get all terms from the node.
    $terms = [];
    foreach ($node->getFields() as $key => $field) {
      if ($field->getFieldDefinition()->getType() == 'entity_reference') {
        $targetType = $field->getFieldDefinition()
          ->getItemDefinition()
          ->getSetting('target_type');
        if ($targetType == 'taxonomy_term') {
          $new_terms = array_map(function (\Drupal\taxonomy\TermInterface $term) {
            return $term->label();
          }, $field->referencedEntities());
          $terms = array_merge($terms, $new_terms);
        }
      }
    }

    // Generate array with the zones config value.
    if (!empty($config->get('digiteka_zones'))) {
      $array_zones = [];
      $digiteka_zones = $config->get('digiteka_zones');
      $digiteka_zones = explode(',', $digiteka_zones);
      foreach ($digiteka_zones as $digiteka_zone) {
        $digiteka_zone = explode(':', $digiteka_zone);
        $key = trim($digiteka_zone[0]);
        $value = trim($digiteka_zone[1]);
        $array_zones[$key] = (int)$value;
      }
    }

    // Loop through node terms and if it matches config, get the zone id.
    foreach ($terms as $term) {
      // If found, set the zone value and end foreach.
      if (isset($array_zones[$term])) {
        $zone = $array_zones[$term];
        break;
      }
    }

    // If it's debug mode, show message just for admins.
    if (!empty($config->get('digiteka_debug_mode'))) {
      $is_admin = \Drupal\user\Entity\User::load(\Drupal::currentUser()->id())->hasRole('administrator');
      if ($is_admin) {
        $debug_message[] = t('DEBUG:');
        $debug_message[] = '---------------------------';
        $debug_message[] = t('Node terms:') . ' ' . implode(',', $terms);
        $debug_message[] = t('Date value:') . ' ' . $ultimedia_date;
        $debug_message[] = t('Zone:') . ' ' . $zone;
        foreach ($debug_message as $message) {
          \Drupal::messenger()->addMessage($message);
        }
      }
    }

    $markup = '<div id="digiteka_wrapper">';
    $markup .= '<div id="ultimedia_wrapper">';
    $markup .= '</div>';
    $markup .= '</div>';
    // @todo Ideally, this should be in digiteka.libraries.yml, but it doesn't work if added there.
    $markup .= '<script type="text/javascript">';
    $markup .= 'var ULTIMEDIA_mdtk="' . $config->get('digiteka_mdtk') . '";';
    $markup .= 'var ULTIMEDIA_date="' . $ultimedia_date . '";';
    $markup .= 'var ULTIMEDIA_target="ultimedia_wrapper";';
    $markup .= 'var ULTIMEDIA_async=false;';
    $markup .= 'var ULTIMEDIA_zone="' . $zone . '";';
    $markup .= '</script>';

    return [
      '#markup' => $markup,
      '#allowed_tags' => ['script', 'div'],
      '#attached' => [
        'library' => ['digiteka/ultimedia'],
      ],
    ];
  }
}
